"use strict";
class BaseError extends Error {
    constructor(options = {}) {
        super();
        this.errorPrefix = 'ERROR_';
        this.name = this.constructor.name;
        const processedOptions = Object.assign({}, BaseError.defaultOptions, options);
        this.code = this.errorPrefix + processedOptions.code;
        this.status = processedOptions.status;
        this.details = processedOptions.details;
        this.innerDetails = processedOptions.innerDetails;
    }
    get message() {
        return (new Date()).toISOString() +
            ' \nERROR_CODE: ' + this.code +
            ' \nERROR_HTTP_STATUS: ' + this.status +
            ' \nERROR_INNER_DETAILS: ' + this._getDetails(this.innerDetails) +
            ' \nERROR_DETAILS: ' + this._getDetails(this.details);
    }
    _jsonReplacer(key, value) {
        if (value instanceof Error) {
            const error = {};
            Object.getOwnPropertyNames(value).forEach((key) => {
                error[key] = value[key];
            });
            return error;
        }
        return value;
    }
    _getDetails(obj) {
        return JSON.stringify(obj, this._jsonReplacer, 2);
    }
}
BaseError.INTERNAL = 'INTERNAL';
BaseError.defaultOptions = {
    code: BaseError.INTERNAL,
    innerDetails: {},
    details: {},
    status: 500
};
exports.BaseError = BaseError;
