"use strict";
const Koa = require("koa");
const jwt = require("koa-jwt");
const bodyParser = require("koa-bodyparser");
const error_middleware_1 = require("./error_middleware");
const success_middleware_1 = require("./success_middleware");
class App {
    constructor(config, router) {
        this.initKoa(config, router);
    }
    initKoa(config, router) {
        const app = new Koa();
        const appPort = config.get('port');
        let jwtSecret = config.has('jwt.secret') ? config.get('jwt.secret') : null;
        app.use(bodyParser());
        app.use(error_middleware_1.errorMiddleware);
        if (jwtSecret) {
            app.use(jwt({ secret: jwtSecret })
                .unless({
                path: [
                    new RegExp(config.get('jwt.publicPath'))
                ]
            }));
        }
        app.use(router.routes());
        app.use(router.allowedMethods());
        app.use(success_middleware_1.successMiddleware);
        app.on('error', (err, ctx) => console.log('REQUEST_ERROR', err, ctx));
        process.on('uncaughtException', (err) => console.log('PROCESS_EXCEPTION', err.stack));
        app.listen(appPort, () => console.log('Server listening on port ' + appPort));
        this.koa = app;
    }
}
exports.App = App;
