"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const base_1 = require("../error/base");
const auth_1 = require("../error/auth");
function errorMiddleware(ctx, next) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield next();
        }
        catch (err) {
            let error;
            if (err instanceof base_1.BaseError) {
                error = err;
            }
            else if (err.status === 401) {
                error = new auth_1.AuthError(auth_1.AuthError.TOKEN_IS_INVALID, process.env.NODE_ENV === 'development' ? ctx.request.headers : {});
            }
            else {
                error = new base_1.BaseError({
                    innerDetails: err
                });
            }
            console.error(error.toString());
            ctx.status = error.status;
            const result = {
                error: error.code
            };
            result.details = error.details;
            ctx.body = result;
        }
    });
}
exports.errorMiddleware = errorMiddleware;
