"use strict";
const validator = require("validator");
const validation_1 = require("../error/validation");
class Validator {
    static isInt(value, min = Number.MIN_SAFE_INTEGER, max = Number.MAX_SAFE_INTEGER) {
        value = Validator.isString(value);
        if (!isNaN(value) && validator.isInt(value)) {
            value = parseInt(value);
            if (value < max && value > min) {
                return value;
            }
            throw new validation_1.ValidationError(validation_1.ValidationError.INT_OUT_OF_BOUNDS);
        }
        throw new validation_1.ValidationError(validation_1.ValidationError.NO_INT);
    }
    static escape(value) {
        return validator.escape(value || '');
    }
    static isString(value, min = 0, max = 256) {
        if (typeof value === 'string') {
            const processedValue = value.trim();
            if (processedValue.length > min && processedValue.length < max) {
                return Validator.escape(processedValue);
            }
            throw new validation_1.ValidationError(validation_1.ValidationError.STRING_OUT_OF_BOUNDS);
        }
        throw new validation_1.ValidationError(validation_1.ValidationError.NO_STRING);
    }
    static isEmail(value) {
        const email = Validator.isString(value).toLowerCase();
        if (validator.isEmail(email)) {
            return email;
        }
        else {
            throw new validation_1.ValidationError(validation_1.ValidationError.NO_EMAIL);
        }
    }
}
exports.Validator = Validator;
